@@ -16,7 +16,7 @@ from .constants import (
 )
 
 
-INTERFACE_KEYS = [
+INTERFACE_KEYS = (
     'address',
     'dns',
     'port',
@@ -28,16 +28,16 @@ INTERFACE_KEYS = [
     'save_config',
     'mtu',
     'table',
-]
+)
 
-PEER_KEYS = [
+PEER_KEYS = (
+    'description',  # We want this to be the first key in the output
     'allowed_ips',
-    'description',
     'endpoint',
     'keepalive',
     'preshared_key',
     'public_key',
-]
+)
 
 
 class Config:  # pylint: disable=too-many-public-methods
@@ -61,6 +61,9 @@ class Config:  # pylint: disable=too-many-public-methods
         Returns the subnets that the remote peer should route to this peer
         """
 
+        if not self._peer.allowed_ips:
+            return None
+
         return value_list_to_comma('AllowedIPs', self._peer.allowed_ips)
 
     @property
@@ -69,8 +72,7 @@ class Config:  # pylint: disable=too-many-public-methods
         Returns the DNS settings of the given peer for the config file
         """
 
-        # do not write empty DNS = entry
-        if not bool(self._peer.dns):
+        if not self._peer.dns:
             return None
 
         return value_list_to_comma('DNS', self._peer.dns)
@@ -190,7 +192,12 @@ class Config:  # pylint: disable=too-many-public-methods
         """
         Returns the Address for this peer
         """
-        return f'Address = {self._peer.address}/{self._peer.address.max_prefixlen}'
+
+        values = []
+        for ip in self._peer.address:  # pylint: disable=invalid-name
+            values.append(f'{ip}/{ip.max_prefixlen}')
+
+        return value_list_to_comma('Address', values)
 
     @property
     def description(self):
@@ -279,7 +286,9 @@ class Config:  # pylint: disable=too-many-public-methods
                 extras.append(self.keepalive)
 
             if extras:
-                peers_data = os.linesep.join((peers_data, *extras))
+                peers_data = os.linesep.join((peers_data, *extras, ""))
+            else:
+                peers_data = os.linesep.join((peers_data, ""))
 
         return peers_data
 
@@ -301,6 +310,7 @@ class Config:  # pylint: disable=too-many-public-methods
             if value:
                 data.append(value)
 
+        data = ('', *data)
         return os.linesep.join(data)
 
     @property
@@ -364,7 +374,15 @@ class ServerConfig(Config):
         """
         Returns the Address for this Server
         """
-        return f'Address = {self._peer.address}/{self._peer.subnet.prefixlen}'
+
+        values = []
+        if self._peer.ipv4:
+            values.append(f'{self._peer.ipv4}/{self._peer.ipv4_subnet.prefixlen}')
+
+        if self._peer.ipv6:
+            values.append(f'{self._peer.ipv6}/{self._peer.ipv6_subnet.prefixlen}')
+
+        return value_list_to_comma('Address', values)
 
     @property
     def peers_filename(self):
